===============
 Release Notes
===============

.. release-notes:: Unreleased

.. release-notes:: Mainline
   :branch: origin/master

.. release-notes:: Newton Series
   :branch: origin/stable/newton
   :earliest-version: 1.9.0
